@@ -13,6 +13,8 @@ TIcurve <- function( lambdas,
                      invertedBackwards = FALSE,
                      energyUnit = "kJ/mol",
                      printValues = TRUE,
+                     printErrors = TRUE,
+                     errorBarThreshold = 0,
                      barePlot = FALSE,
                      ... )
 {
@@ -78,10 +80,24 @@ TIcurve <- function( lambdas,
                       pch = 19, cex = 0.6,
                       col = VEC_colours[ i ],
                       ... )
-  plot_segments( lambdas[[ i ]][ , 1:2 ],
-                 lambdas[[ i ]][ , 3 ],
-                 0.01,
-                 col = VEC_colours[ i ] )
+  if( printErrors )
+  {
+    MAT_positions <- lambdas[[ i ]][ , 1:2 ]
+    VEC_errors <- lambdas[[ i ]][ , 3 ]
+    for( j in nrow( MAT_positions ):1 )
+    {
+      if( VEC_errors[ j ] <= errorBarThreshold )
+      {
+        VEC_errors <- VEC_errors[ -j ]
+        MAT_positions <- MAT_positions[ -j, ]
+      }
+    }
+    VEC_curColours <- rep( VEC_colours[ i ], times = nrow( MAT_positions ) )
+    plot_segments( MAT_positions,
+                   VEC_errors,
+                   0.01,
+                   col = VEC_curColours )
+  }
   par( new = TRUE )
   plot( lambdas[[ i ]],
         ylim = VEC_valueLimits, yaxt = "n", ylab = "",
@@ -97,6 +113,11 @@ TIcurve <- function( lambdas,
   INT_significantForward <- get_sign_digits( REAL_forward_error )
   REAL_forward_integral_rounded <- round( REAL_forward_integral, digits = INT_significantForward )
   REAL_forward_error_rounded <- round( REAL_forward_error, digits = INT_significantForward )
+  MAT_integrationResults <- matrix( c( REAL_forward_integral_rounded, REAL_forward_error_rounded ),
+                                    ncol = 2 )
+  colnames( MAT_integrationResults ) <- c( "deltaG", "error" )
+  rownames( MAT_integrationResults ) <- c( "forward" )
+  REAL_hysteresis <- NA
   if( !barePlot && printValues )
     mtext( side = 1, line = 4.75, cex = 1.0,
            adj = 1,
@@ -116,6 +137,9 @@ TIcurve <- function( lambdas,
     INT_significantBackward <- get_sign_digits( REAL_backward_error )
     REAL_backward_integral_rounded <- round( REAL_backward_integral, digits = INT_significantBackward )
     REAL_backward_error_rounded <- round( REAL_backward_error, digits = INT_significantBackward )
+    MAT_integrationResults <- rbind( MAT_integrationResults,
+                                     c( REAL_backward_integral_rounded, REAL_backward_error_rounded ) )
+    rownames( MAT_integrationResults ) <- c( "forward", "backward" )
     mtext( side = 1, line = 6.0, cex = 1.0,
            adj = 1,
            text = substitute( paste( Delta, "G"["back"], " = ",
@@ -140,4 +164,9 @@ TIcurve <- function( lambdas,
                                             sep = "" ) ) ) )
   }
   #########
+  
+  LIST_return <- list( lambdapoints = lambdas,
+                       integrationresults = MAT_integrationResults,
+                       hysteresis = REAL_hysteresis )
+  return( LIST_return )
 }
\ No newline at end of file
